@@ -10,6 +10,7 @@ from pydantic.schema import Generic
 from pydantic.utils import GetterDict
 
 from workplanner.enums import Statuses, Operators
+from workplanner.utils import normalize_datetime
 
 if TYPE_CHECKING:
     from workplanner import models
@@ -45,6 +46,10 @@ class WorkplanManyPK(pydantic.BaseModel):
     name: pydantic.constr(max_length=255)
     worktime_utc_list: list[pendulum.DateTime]
 
+    _worktime_utc_list = validator('worktime_utc_list', allow_reuse=True)(
+        lambda wt_list: list(map(normalize_datetime, wt_list))
+    )
+
     def get_items(self) -> peewee.ModelSelect:
         from workplanner import crud
 
@@ -60,6 +65,8 @@ class WorkplanPK(pydantic.BaseModel):
     name: pydantic.constr(max_length=255)
     worktime_utc: pendulum.DateTime
 
+    _worktime_utc = validator('worktime_utc', allow_reuse=True)(normalize_datetime)
+
     def get_item(self) -> Optional["models.Workplan"]:
         from workplanner import crud
 
@@ -95,6 +102,10 @@ class WorkplanUpdate(WorkplanPK):
     started_utc: Optional[dt.datetime] = None
     finished_utc: Optional[dt.datetime] = None
 
+    _expires_utc = validator('expires_utc', allow_reuse=True)(normalize_datetime)
+    _started_utc = validator('started_utc', allow_reuse=True)(normalize_datetime)
+    _finished_utc = validator('finished_utc', allow_reuse=True)(normalize_datetime)
+
     def save(self) -> Optional["Workplan"]:
         from workplanner import crud
 
@@ -119,6 +130,12 @@ class Workplan(WorkplanPK):
     created_utc: pendulum.DateTime
     updated_utc: pendulum.DateTime
 
+    _expires_utc = validator('expires_utc', allow_reuse=True)(normalize_datetime)
+    _started_utc = validator('started_utc', allow_reuse=True)(normalize_datetime)
+    _finished_utc = validator('finished_utc', allow_reuse=True)(normalize_datetime)
+    _created_utc = validator('created_utc', allow_reuse=True)(normalize_datetime)
+    _updated_utc = validator('updated_utc', allow_reuse=True)(normalize_datetime)
+
     class Config:
         orm_mode = True
         getter_dict = PeeweeGetterDict
@@ -163,6 +180,8 @@ class GenerateWorkplans(pydantic.BaseModel):
         Union[pydantic.PositiveInt, list[pydantic.NegativeInt]]
     ] = None
 
+    _start_time = validator('start_time', allow_reuse=True)(normalize_datetime)
+
 
 class Error(pydantic.BaseModel):
     code: int
@@ -268,6 +287,13 @@ class WorkplanQueryFilter(WorkplanPK):
     created_utc: list[DateTimeT] = None
     updated_utc: list[DateTimeT] = None
 
+    _worktime_utc = validator('worktime_utc', allow_reuse=True)(normalize_datetime)
+    _expires_utc = validator('expires_utc', allow_reuse=True)(normalize_datetime)
+    _started_utc = validator('started_utc', allow_reuse=True)(normalize_datetime)
+    _finished_utc = validator('finished_utc', allow_reuse=True)(normalize_datetime)
+    _updated_utc = validator('updated_utc', allow_reuse=True)(normalize_datetime)
+    _created_utc = validator('created_utc', allow_reuse=True)(normalize_datetime)
+
     def set_where(self, query: "WorkplanQueryT") -> "WorkplanQueryT":
         from workplanner import models
 
